from setuptools import setup

setup(name='vqsr_cnn',
      version='0.0.7',
      description='Variant quality score recalibration with Convolutional Neural Networks',
      url='https://github.com/broadinstitute/dsde-deep-learning',
      author='Sam Friedman',
      author_email='sam@broadinstitute.org',
      license='MIT',
      packages=['vqsr_cnn'],
      zip_safe=False)